==> jc-1.4.0.tar.gz: javax/swing/RepaintManager__24RepaintWorker.h <==
// public class javax.swing.RepaintManager$RepaintWorker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7284961b6806a160 javax_swing_RepaintManager__24RepaintWorker

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_RepaintManager__24RepaintWorker_H_
#define _JC_javax_swing_RepaintManager__24RepaintWorker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_RepaintManager$object;

// Typedefs
typedef struct _jc_javax_swing_RepaintManager__24RepaintWorker$sub_refs	_jc_javax_swing_RepaintManager__24RepaintWorker$sub_refs;
typedef struct _jc_javax_swing_RepaintManager__24RepaintWorker$sub_nonrefs	_jc_javax_swing_RepaintManager__24RepaintWorker$sub_nonrefs;
typedef struct _jc_javax_swing_RepaintManager__24RepaintWorker$refs	_jc_javax_swing_RepaintManager__24RepaintWorker$refs;
typedef struct _jc_javax_swing_RepaintManager__24RepaintWorker$nonrefs	_jc_javax_swing_RepaintManager__24RepaintWorker$nonrefs;
typedef struct _jc_javax_swing_RepaintManager__24RepaintWorker$object	_jc_javax_swing_RepaintManager__24RepaintWorker$object;

typedef const struct _jc_javax_swing_RepaintManager__24RepaintWorker$vmethods	_jc_javax_swing_RepaintManager__24RepaintWorker$vmethods;
typedef const struct _jc_javax_swing_RepaintManager__24RepaintWorker$vtable	_jc_javax_swing_RepaintManager__24RepaintWorker$vtable;
typedef const struct _jc_javax_swing_RepaintManager__24RepaintWorker$vtype	_jc_javax_swing_RepaintManager__24RepaintWorker$vtype;

// Constructors
extern void _jc_javax_swing_RepaintManager__24RepaintWorker$method$_init$e9b5b1cce33026b5(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *, struct _jc_javax_swing_RepaintManager$object *);

// Virtual methods
extern jboolean _jc_javax_swing_RepaintManager__24RepaintWorker$method$isLive$2197f76e6b3ee2a0(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *);
extern void _jc_javax_swing_RepaintManager__24RepaintWorker$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *);
extern void _jc_javax_swing_RepaintManager__24RepaintWorker$method$setLive$7379a0492e1ecc5b(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_RepaintManager__24RepaintWorker$method_info$isLive$2197f76e6b3ee2a0;
extern _jc_method _jc_javax_swing_RepaintManager__24RepaintWorker$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_javax_swing_RepaintManager__24RepaintWorker$method_info$setLive$7379a0492e1ecc5b;

// Virtual methods structure
struct _jc_javax_swing_RepaintManager__24RepaintWorker$vmethods {
	jboolean	(*isLive$2197f76e6b3ee2a0)(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *);
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *);
	void	(*setLive$7379a0492e1ecc5b)(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *, jboolean);
};

// Vtable
struct _jc_javax_swing_RepaintManager__24RepaintWorker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_RepaintManager__24RepaintWorker$vmethods	javax_swing_RepaintManager__24RepaintWorker;
};

// Vtype
struct _jc_javax_swing_RepaintManager__24RepaintWorker$vtype {
	_jc_type			type;
	_jc_javax_swing_RepaintManager__24RepaintWorker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_RepaintManager__24RepaintWorker$sub_refs {
	struct _jc_javax_swing_RepaintManager$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_RepaintManager__24RepaintWorker$refs {
    _jc_javax_swing_RepaintManager__24RepaintWorker$sub_refs	javax_swing_RepaintManager__24RepaintWorker;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_RepaintManager__24RepaintWorker$sub_nonrefs {
	jboolean	live;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_RepaintManager__24RepaintWorker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_RepaintManager__24RepaintWorker$sub_nonrefs	javax_swing_RepaintManager__24RepaintWorker;
};

// Object instance structure
struct _jc_javax_swing_RepaintManager__24RepaintWorker$object {
	_jc_javax_swing_RepaintManager__24RepaintWorker$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_RepaintManager__24RepaintWorker$vtype	*vtype;
	_jc_javax_swing_RepaintManager__24RepaintWorker$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_RepaintManager__24RepaintWorker$vtype _jc_javax_swing_RepaintManager__24RepaintWorker$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_RepaintManager__24RepaintWorker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_RepaintManager__24RepaintWorker$class_object;

#endif	/* _JC_javax_swing_RepaintManager__24RepaintWorker_H_ */

==> jc-1.4.6.tar.gz: javax/swing/RepaintManager__24RepaintWorker.h <==
// public class javax.swing.RepaintManager$RepaintWorker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 61965ed2e4e0230 javax_swing_RepaintManager__24RepaintWorker

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_RepaintManager__24RepaintWorker_H_
#define _JC_javax_swing_RepaintManager__24RepaintWorker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_RepaintManager$object;

// Typedefs
typedef struct _jc_javax_swing_RepaintManager__24RepaintWorker$sub_refs	_jc_javax_swing_RepaintManager__24RepaintWorker$sub_refs;
typedef struct _jc_javax_swing_RepaintManager__24RepaintWorker$sub_nonrefs	_jc_javax_swing_RepaintManager__24RepaintWorker$sub_nonrefs;
typedef struct _jc_javax_swing_RepaintManager__24RepaintWorker$refs	_jc_javax_swing_RepaintManager__24RepaintWorker$refs;
typedef struct _jc_javax_swing_RepaintManager__24RepaintWorker$nonrefs	_jc_javax_swing_RepaintManager__24RepaintWorker$nonrefs;
typedef struct _jc_javax_swing_RepaintManager__24RepaintWorker$object	_jc_javax_swing_RepaintManager__24RepaintWorker$object;

typedef const struct _jc_javax_swing_RepaintManager__24RepaintWorker$vmethods	_jc_javax_swing_RepaintManager__24RepaintWorker$vmethods;
typedef const struct _jc_javax_swing_RepaintManager__24RepaintWorker$vtable	_jc_javax_swing_RepaintManager__24RepaintWorker$vtable;
typedef const struct _jc_javax_swing_RepaintManager__24RepaintWorker$vtype	_jc_javax_swing_RepaintManager__24RepaintWorker$vtype;

// Constructors
extern void _jc_javax_swing_RepaintManager__24RepaintWorker$method$_init$e9b5b1cce33026b5(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *, struct _jc_javax_swing_RepaintManager$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_swing_RepaintManager__24RepaintWorker$method$isLive$2197f76e6b3ee2a0(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_RepaintManager__24RepaintWorker$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_RepaintManager__24RepaintWorker$method$setLive$7379a0492e1ecc5b(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_RepaintManager__24RepaintWorker$method_info$isLive$2197f76e6b3ee2a0;
extern _jc_method _jc_javax_swing_RepaintManager__24RepaintWorker$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_javax_swing_RepaintManager__24RepaintWorker$method_info$setLive$7379a0492e1ecc5b;

// Virtual methods structure
struct _jc_javax_swing_RepaintManager__24RepaintWorker$vmethods {
	jboolean	(*isLive$2197f76e6b3ee2a0)(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *) _JC_JCNI_ATTR;
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *) _JC_JCNI_ATTR;
	void	(*setLive$7379a0492e1ecc5b)(_jc_env *, struct _jc_javax_swing_RepaintManager__24RepaintWorker$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_RepaintManager__24RepaintWorker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_RepaintManager__24RepaintWorker$vmethods	javax_swing_RepaintManager__24RepaintWorker;
};

// Vtype
struct _jc_javax_swing_RepaintManager__24RepaintWorker$vtype {
	_jc_type			type;
	_jc_javax_swing_RepaintManager__24RepaintWorker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_RepaintManager__24RepaintWorker$sub_refs {
	struct _jc_javax_swing_RepaintManager$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_RepaintManager__24RepaintWorker$refs {
    _jc_javax_swing_RepaintManager__24RepaintWorker$sub_refs	javax_swing_RepaintManager__24RepaintWorker;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_RepaintManager__24RepaintWorker$sub_nonrefs {
	jboolean	live;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_RepaintManager__24RepaintWorker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_RepaintManager__24RepaintWorker$sub_nonrefs	javax_swing_RepaintManager__24RepaintWorker;
};

// Object instance structure
struct _jc_javax_swing_RepaintManager__24RepaintWorker$object {
	_jc_javax_swing_RepaintManager__24RepaintWorker$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_RepaintManager__24RepaintWorker$vtype	*vtype;
	_jc_javax_swing_RepaintManager__24RepaintWorker$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_RepaintManager__24RepaintWorker$vtype _jc_javax_swing_RepaintManager__24RepaintWorker$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_RepaintManager__24RepaintWorker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_RepaintManager__24RepaintWorker$class_object;

#endif	/* _JC_javax_swing_RepaintManager__24RepaintWorker_H_ */
